Abacus.AI API Python API Client [![PyPI version](https://badge.fury.io/py/abacusai.svg)](https://badge.fury.io/py/abacusai)
============

The official Python API Client Library for Abacus.AI.

## Install

```console
$ pip install abacusai
```

## Documentation

Function Documentation: https://abacusai.github.io/api-python/autoapi/abacusai/index.html

For a full list of APIs and code snippet examples, see the [Abacus.AI Documentation](https://abacus.ai/app/help/ref/overview).

## Getting Started

### Calling an API

To call an API, you must first instantiate an `ApiClient`.

```python
from abacusai import ApiClient
client = ApiClient('YOUR_API_KEY')
```

## License
[MIT](https://github.com/abacusai/api-python/blob/main/LICENSE)
